@@ -1,5 +1,5 @@
 rhmm.hmm.discnp <- function(model,...,nsim=1,verbose=FALSE,
-                            inMiss=TRUE,fep=NULL,drop=TRUE) {
+                            inMiss=TRUE,fep=NULL,drop=TRUE,forceNumeric=TRUE) {
 #
 # Function rhmm.hmm to simulate data from a fitted hidden Markov
 # model with discrete emissions, the probabilities of which are
@@ -15,9 +15,8 @@ ispd <- model$ispd
 yval <- if(is.null(model$y)) NULL else attr(model$y,"uval")
 nafrac <- if(inMiss) model$nafrac else NULL
 
-
 ylengths <- model$ylengths
 rhmm.default(ylengths=ylengths,nsim=nsim,verbose=verbose,
              nafrac=nafrac,fep=fep,tpm=tpm,Rho=Rho,ispd=ispd,
-             yval=yval,drop=drop)
+             yval=yval,drop=drop,forceNumeric=forceNumeric)
 }
