@@ -10,7 +10,7 @@
 extern void F77_NAME(getgl)(double *, int *, int *,double *, double *, double *,int *, int *, int *, double *, int *, double *, double *, double *, double *, double *, double *);
 extern void F77_NAME(gethgl)(double *, int *, int *, double *, double *, double *, double *, int *, int *, int *, double *, double *, int *, double *, double *, double *, double *, double *, double *, double *, double *, double *, double *, double *, double *);
 extern void F77_NAME(getl)(double *, double *, double *, int *, int *, double *, double *, double *);
-extern void F77_NAME(recurse)(double *, double *, double *, int *, double *, int *, int *, int *, double *, double *, double *, int *, int *, double *, double *, double *, double *, double *);
+extern void F77_NAME(recurse)(double *, double *, double *, int *, double *, int *, int *, int *, int *, double *, double *, int *, int *, double *, double *, double *, double *, double *);
 
 static const R_FortranMethodDef FortranEntries[] = {
     {"getgl",   (DL_FUNC) &F77_NAME(getgl),   17},
